﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace MyFriend.Common
{
   public class Commons
    {
        /// <summary>
        /// 最新分页程序
        /// </summary>
        /// <param name="totalNum"></param>
        /// <param name="pageSize"></param>
        /// <param name="curPage"></param>
        /// <param name="urlPathFormat"></param>
        /// <param name="maxPageNum"></param>
        /// <returns></returns>
        public static string Paginatioin(int totalNum, int pageSize, int curPage, string urlPathFormat)
        {
            if (totalNum <= pageSize) return string.Empty;//不足一页

            #region 配置参数

            //PageNum = PageNumBeforeCur + 1 + PageNumAfterCur;
            int PageNum = 5; //除首尾外，最多显示页码个数。
            int PageNumBeforeCur = 2;//当前页面前显示个数
            int PageNumAfterCur = 2;//当前页面后显示个数

            #endregion

            #region 临时参数

            int totalPage, lastPage;
            totalPage = lastPage = (int)Math.Ceiling((double)totalNum / pageSize);
            totalPage = lastPage;

            int pageStar = 2;
            int pageFinish = totalPage - 1;
            bool showFrontDots = false;
            bool showBehindDots = false;

            #endregion

            #region 计算除首尾外部分
            if (totalPage > PageNum + 2)
            {
                int tmpStarNum = curPage - PageNumBeforeCur;
                int tmpFinishNum = curPage + PageNumAfterCur;

                //左边不足，整体右移补足PageNum个
                if (tmpStarNum < 2)
                {
                    int offset = 2 - tmpStarNum;
                    tmpStarNum += offset;
                    tmpFinishNum += offset;
                    showFrontDots = false;
                    showBehindDots = true;
                }
                else if (tmpFinishNum > totalPage - 1)
                {
                    int offset = tmpFinishNum - (totalPage - 1);
                    tmpStarNum -= offset;
                    tmpFinishNum -= offset;
                    showFrontDots = true;
                    showBehindDots = false;
                }
                else if (tmpStarNum >= 2 && tmpFinishNum <= (totalPage - 1))
                {
                    showFrontDots = tmpStarNum > 2;
                    showBehindDots = tmpFinishNum < (totalPage - 1);
                }

                pageStar = tmpStarNum;
                pageFinish = tmpFinishNum;
            }
            #endregion

            #region 拼接字符输入
            StringBuilder html = new StringBuilder();
            html.Append("<div class=\"pages\" id=\"paginator\">");

            html.Append("<table class=\"ispage\">");
            html.Append("<tbody><tr>");

            #region 上一页
            if (curPage != 1)
            {
                html.Append("<td><a href=\"" + string.Format(urlPathFormat, curPage - 1) + "\" class=\"prev\">上一页</a></td>");
            }
            #endregion

            #region 中部页面区域
            //if (totalPages >= 2 && pageFrom > 2) htmlPage.AppendFormat("<a href=\"{0}\">1</a><span class=\"omit\">&hellip;</span>", string.Format(urlPathAndParam, 1));
            html.Append(curPage == 1 ? "<td><b>1</b></td>" : string.Format("<td><a href=\"{0}\">1</a></td>", string.Format(urlPathFormat, 1)));

            if (showFrontDots)
            {
                html.Append("<td><span class=\"omit\">&hellip;</span></td>");
            }

            for (int i = pageStar; i <= pageFinish; i++)
            {
                html.Append(i == curPage ? "<td><b>" + i + "</b></td>" : "<td><a href=\"" + string.Format(urlPathFormat, i) + "\">" + i + "</a></td>");
            }

            if (showBehindDots)
            {
                html.Append("<td><span class=\"omit\">&hellip;</span></td>");
            }

            html.Append(curPage == lastPage ? string.Format("<td><b>{0}</b></td>", lastPage) : string.Format("<td><a href=\"{0}\">{1}</a></td>", string.Format(urlPathFormat, lastPage), lastPage));
            #endregion


            #region 下一页
            if (curPage != lastPage)
            {
                html.Append("<td><a href=\"" + string.Format(urlPathFormat, (curPage + 1)) + "\" class=\"next\">下一页</a></td>");
            }
            #endregion

            html.Append("</tr></tbody></table>");
            html.Append("</div>");
            #endregion

            return html.ToString();
        }
 

    }
}
